require 'rest-client'

module Octobot
  module SlackAgent

    GOOD = 'good'
    WARNING = 'warning'
    DANGER = 'danger'

    class Notifier

      attr_accessor :webhook_url, :username, :icon_emoji

      def initialize(webhook_url, username='octobot', icon_emoji=nil)
        @webhook_url = webhook_url
        @username = username
        @icon_emoji = icon_emoji
      end

      def success(params)
        send_attachments [ attachment(params, GOOD) ]
      end

      def warn(params)
        send_attachments [ attachment(params, WARNING) ]
      end

      def error(params)
        send_attachments [ attachment(params, DANGER) ]
      end

      def send_attachments(attachments)
        send attachments: attachments
      end

      def send(params)
        send_request(base_params.merge(params))
      end

      private
      def send_request(data)
        RestClient.post webhook_url, data.to_json
      end

      def base_params
        bp = {}
        bp[:username] = username if username
        bp[:octobot] = username if icon_emoji

        bp
      end

      def attachment(params, color=nil)
        base_attachment = {
            fallback: "#{params[:title]}\n\n#{params[:text]}",
        }

        base_attachment[:color] = color if color

        base_attachment.merge(params)
      end
    end
  end
end
